pub struct WizardSettings { /* private fields */ }Implementations
Sourceimpl WizardSettings
impl WizardSettings
pub fn read_from<R>(reader: R, version: InnoVersion) -> Result<Self>where
R: Read,
Sourcepub const fn image_alpha_format(&self) -> ImageAlphaFormat
pub const fn image_alpha_format(&self) -> ImageAlphaFormat
Returns the image alpha format.
Sourcepub const fn image_back_color(&self) -> Color
pub const fn image_back_color(&self) -> Color
Returns the image background color.
Sourcepub const fn small_image_back_color(&self) -> Color
pub const fn small_image_back_color(&self) -> Color
Returns the small image background color.
Sourcepub const fn image_back_color_dynamic_dark(&self) -> Color
pub const fn image_back_color_dynamic_dark(&self) -> Color
Returns the image background color used in dark mode when a dynamic theme is enabled.
Sourcepub const fn small_image_back_color_dynamic_dark(&self) -> Color
pub const fn small_image_back_color_dynamic_dark(&self) -> Color
Returns the small image background color used in dark mode when a dynamic theme is enabled.
Sourcepub const fn image_opacity(&self) -> Option<u8>
pub const fn image_opacity(&self) -> Option<u8>
Returns the image opacity.
Sourcepub const fn back_image_opacity(&self) -> Option<u8>
pub const fn back_image_opacity(&self) -> Option<u8>
Returns the background image opacity.
Added in Inno Setup 6.7.0.
Sourcepub const fn size_percent(&self) -> WizardSizePercent
pub const fn size_percent(&self) -> WizardSizePercent
Returns the wizard size percent
Sourcepub const fn style(&self) -> WizardStyle
pub const fn style(&self) -> WizardStyle
Returns the wizard style.